@@ -1,5 +1,5 @@
 import os
-import shutil
+import re
 import nbformat
 from nbconvert import MarkdownExporter
 from nbconvert.writers import FilesWriter
@@ -36,4 +36,17 @@ def generate_readme(notebook_path, dir_path, filename):
     c.FilesWriter.build_directory = index_files
     fw = FilesWriter(config=c)
     fw.write(output, resources, notebook_name=filename)
-    shutil.move(input_path, output_path)
\ No newline at end of file
+    
+    old_readme_file = open(input_path, 'r')
+    old_readme = old_readme_file.read()
+    old_readme_file.close()
+    os.remove(input_path)
+    pattern = '!\[[^\]]*\]\((.*?)\s*("(?:.*[^"])")?\s*\)'
+    image_paths = re.findall(pattern, old_readme)
+    new_readme = str(old_readme)
+    for path in image_paths:
+        new_readme = new_readme.replace(path, path.replace('(', '(index_files/'))
+
+    readme_file = open(output_path, 'w')
+    readme_file.write(new_readme)
+    readme_file.close()
\ No newline at end of file
