@@ -1,3 +1,7 @@
+"""
+Base class for tests. Primarily provides Markdown Outputs.
+"""
+
 from IPython.display import display, Markdown
 
 class BaseTest:
@@ -10,7 +14,9 @@ class BaseTest:
         display(markdown)
             
     def print_results(self, key, test, *args, main=False, output=False):
-        if main:
+        if main and output:
+            result = test(self, True)
+        elif main:
             result = test(self)
         else:
             result = test(*args)
